#!/usr/bin/env python3

"""

**Description**

Some datasets commonly used in meta-learning vision tasks.
"""

from .full_omniglot import FullOmniglot
from .mini_imagenet import MiniImagenet
from .tiered_imagenet import TieredImagenet
from .cifarfs import CIFARFS
from .fc100 import FC100
from .vgg_flowers import VGGFlower102
from .fgvc_aircraft import FGVCAircraft
from .cu_birds200 import CUBirds200
from .describable_textures import DescribableTextures
from .quickdraw import Quickdraw
from .fgvc_fungi import FGVCFungi
